@@ -84,7 +84,7 @@ test with special configuration once, without affecting other code:
 
 =cut
 
-our $VERSION = '0.001';
+our $VERSION = '0.001001';
 our @EXPORT = qw/analyse_code star_rating_of_warnings/;
 our @EXPORT_OK = (@EXPORT, qw/test_lines test_clang_tidy/);
 our %EXPORT_TAGS = (default => \@EXPORT, all => \@EXPORT_OK);
@@ -217,6 +217,13 @@ our %clang_tidy_check_options = (
 	'readability-implicit-bool-conversion.AllowIntegerConditions' => 1,
 );
 
+sub _clang_tidy_exists {
+	# does clang-tidy exist?
+	# run it with no arguments, see if exit code is 127
+	system 'clang-tidy 2>/dev/null 1>/dev/null';
+	$? >> 8 != 127
+}
+
 sub test_clang_tidy {
 	my %args = @_;
 	my $extension = $extension_of_language{uc $args{language}};
@@ -243,7 +250,11 @@ sub test_clang_tidy {
 	};
 
 	my @output = qx,clang-tidy -config='$config' -quiet $fh 2>/dev/null,;
-	if ($? != 0 && $? != 256) {
+	my $exit_code = $? >> 8; # this is usually the number of clang-tidy errors
+	my $signal = $? & 127;
+	if ($signal || ($exit_code == 127 && !_clang_tidy_exists)) {
+		# special case: exit code 127 could mean "127 errors found" or
+		# "clang-tidy not found"
 		carp "Failed to run clang-tidy, \$? is $?";
 		return
 	}
